@@ -41,7 +41,7 @@ Provides:
   9. SelectionActions: Actions on the grid selection
   10. FindActions: Actions for finding and replacing
   11. AllGridActions: All grid actions as a bundle
-  
+
 
 """
 
@@ -54,7 +54,7 @@ from src.config import config
 
 from src.gui._grid_table import GridTable
 from src.lib.parsers import get_font_from_data
-from src.lib.gpg import sign, verify, is_pyme_present
+from src.lib.gpg import sign, verify
 from src.lib.selection import Selection
 
 from src.actions._main_window_actions import Actions
@@ -71,21 +71,21 @@ from src.gui._events import ResizeGridMsg, GridActionTableSwitchMsg
 
 class FileActions(Actions):
     """File actions on the grid"""
-    
+
     def __init__(self, grid):
         Actions.__init__(self, grid)
-        
+
         self.saving = False
-        
-        self.main_window.Bind(EVT_COMMAND_GRID_ACTION_OPEN, self.open) 
+
+        self.main_window.Bind(EVT_COMMAND_GRID_ACTION_OPEN, self.open)
         self.main_window.Bind(EVT_COMMAND_GRID_ACTION_SAVE, self.save)
 
     def _is_aborted(self, cycle, statustext, total_elements=None, freq=1000):
         """Displays progress and returns True if abort
-        
+
         Parameters
         ----------
-        
+
         statustext: String
         \tLeft text in statusbar to be displayed
         cycle: Integer
@@ -94,9 +94,9 @@ class FileActions(Actions):
         \tThe number of elements that have to be processed
         freq: Integer, defaults to 1000
         \tNo. operations between two abort possibilities
-        
+
         """
-        
+
         # Show progress in statusbar each freq (1000) cells
         if cycle % freq == 0:
             # See if we know how much data comes along
@@ -104,172 +104,170 @@ class FileActions(Actions):
                 total_elements_str = ""
             else:
                 total_elements_str = " of " + str(total_elements)
-                
+
             statustext = statustext + str(cycle) + total_elements_str + \
                         " elements processed. Press <Esc> to abort."
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
-            
+
             # Now wait for the statusbar update to be written on screen
             wx.Yield()
-            
+
             # Abort if we have to
             if self.need_abort:
                 # We have to abort`
                 return True
-                
+
         # Continue
         return False
 
     def validate_signature(self, filename):
         """Returns True if a valid signature is present for filename"""
-        
+
         sigfilename = filename + '.sig'
-        
+
         try:
             dummy = open(sigfilename)
             dummy.close()
         except IOError:
             # Signature file does not exist
             return False
-        
+
         # Check if the sig is valid for the sigfile
         return verify(sigfilename, filename)
 
     def enter_safe_mode(self):
         """Enters safe mode"""
-        
+
         self.code_array.safe_mode = True
 
     def leave_safe_mode(self):
         """Leaves save mode"""
-        
+
         self.code_array.safe_mode = False
         self.code_array.result_cache.clear()
         post_command_event(self.main_window, SafeModeExitMsg)
-        
+
     def approve(self, filepath):
         """Sets safe mode if signature missing of invalid"""
-        
+
         if self.validate_signature(filepath):
             self.leave_safe_mode()
             post_command_event(self.main_window, SafeModeExitMsg)
-            
+
             statustext = "Valid signature found. File is trusted."
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
-            
+
         else:
             self.enter_safe_mode()
             post_command_event(self.main_window, SafeModeEntryMsg)
-            
+
             statustext = "File is not properly signed. Safe mode " + \
                          "activated. Select File -> Approve to leave safe mode."
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
 
     def _get_file_version(self, infile):
         """Returns infile version string."""
-        
+
         # Determine file version
         for line1 in infile:
             if line1.strip() != "[Pyspread save file version]":
                 raise ValueError, "File format unsupported."
             break
-            
+
         for line2 in infile:
             return line2.strip()
 
     def _abort_open(self, filepath, infile):
         """Aborts file open"""
-        
+
         statustext = "File loading aborted."
         post_command_event(self.main_window, StatusBarMsg, text=statustext)
-        
+
         infile.close()
-        
+
         self.opening = False
         self.need_abort = False
 
     def clear(self, shape=None):
         """Empties grid and sets shape to shape
-        
+
         Clears all attributes, row heights, column withs and frozen states.
         Empties undo/redo list and caches.
-        
+
         Properties
         ----------
-        
+
         shape: 3-tuple of Integer, defaults to None
         \tTarget shape of grid after clearing all content.
         \tShape unchanged if None
-        
+
         """
-        
+
         # Clear cells
         self.code_array.dict_grid.clear()
-        
+
         # Clear attributes
         del self.code_array.dict_grid.cell_attributes[:]
-        
+
         if shape is not None:
             # Set shape
             self.code_array.shape = shape
-        
+
         # Clear row heights and column widths
         self.code_array.row_heights.clear()
         self.code_array.col_widths.clear()
-        
+
         # Clear caches
         self.code_array.unredo.reset()
         self.code_array.result_cache.clear()
-        
 
-    
     def open(self, event):
         """Opens a file that is specified in event.attr
-        
+
         Parameters
         ----------
         event.attr: Dict
         \tkey filepath contains file path of file to be loaded
-        
+
         """
-        
+
         filepath = event.attr["filepath"]
-        
+
         # Set states for file open
-        
+
         self.opening = True
         self.need_abort = False
-        
+
         try:
             infile = bz2.BZ2File(filepath, "r")
-            
+
         except IOError:
             statustext = "Error opening file " + filepath + "."
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
-            
+
             return False
-        
+
         # Make loading safe
         self.approve(filepath)
-        
+
         # Abort if file version not supported
         try:
             version = self._get_file_version(infile)
             if version != "0.1":
                 statustext = "File version " + version + \
                              "unsupported (not 0.1)."
-                post_command_event(self.main_window, StatusBarMsg, 
+                post_command_event(self.main_window, StatusBarMsg,
                                    text=statustext)
                 return False
-            
+
         except (IOError, ValueError), errortext:
             post_command_event(self.main_window, StatusBarMsg, text=errortext)
-        
+
         # Parse content
 
         def parser(*args):
             """Dummy parser. Raises ValueError"""
-            
+
             raise ValueError, "No section parser present."
 
         section_readers = { \
@@ -280,10 +278,10 @@ class FileActions(Actions):
             "[col_widths]": self.code_array.dict_grid.parse_to_width,
             "[macros]": self.code_array.dict_grid.parse_to_macro,
         }
-        
+
         # Disable undo
         self.grid.code_array.unredo.active = True
-        
+
         try:
             for cycle, line in enumerate(infile):
                 stripped_line = line.decode("utf-8").strip()
@@ -298,109 +296,108 @@ class FileActions(Actions):
                         if parser == self.code_array.dict_grid.parse_to_shape:
                             # Empty grid
                             self.clear(self.code_array.shape)
-                            
+
                             self.grid.GetTable().ResetView()
                 else:
                     pass
-                
+
                 # Enable abort during long saves
                 if self._is_aborted(cycle, "Loading file... "):
                     self._abort_open(filepath, infile)
                     return False
-        
+
         except IOError:
             statustext = "Error opening file " + filepath + "."
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
-            
+
             return False
-        
+
         except EOFError:
             # Normally on empty grids
             pass
-        
+
         infile.close()
         self.opening = False
-        
+
         # Enable undo again
         self.grid.code_array.unredo.active = False
-        
+
         self.grid.GetTable().ResetView()
         self.grid.ForceRefresh()
-        
+
         # File sucessfully opened. Approve again to show status.
         self.approve(filepath)
-        
+
     def sign_file(self, filepath):
         """Signs file if possible"""
-        
-        if is_pyme_present():
-            signature = sign(filepath)
-            signfile = open(filepath + '.sig','wb')
-            signfile.write(signature)
-            signfile.close()
-            
-            # Statustext differs if a save has occurred
-            
-            if self.code_array.safe_mode:
-                statustext = 'File saved and signed'
-            else:
-                statustext = 'File signed'
-                
+
+        signature = sign(filepath)
+        if signature is None:
+            statustext = 'Error signing file. File is not signed.'
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
-            
+            return
+
+        signfile = open(filepath + '.sig', 'wb')
+        signfile.write(signature)
+        signfile.close()
+
+        # Statustext differs if a save has occurred
+
+        if self.code_array.safe_mode:
+            statustext = 'File saved and signed'
         else:
-            msg = 'Cannot sign the file. Maybe PyMe is not installed.'
-            short_msg = 'Cannot sign file!'
-            self.main_window.interfaces.display_warning(msg, short_msg)
+            statustext = 'File signed'
+
+        post_command_event(self.main_window, StatusBarMsg, text=statustext)
 
     def _abort_save(self, filepath, outfile):
         """Aborts file save"""
-        
+
         statustext = "Save aborted."
         post_command_event(self.main_window, StatusBarMsg, text=statustext)
-        
+
         outfile.close()
         os.remove(filepath)
-        
+
         self.saving = False
         self.need_abort = False
-    
+
     def save(self, event):
         """Saves a file that is specified in event.attr
-        
+
         Parameters
         ----------
         event.attr: Dict
         \tkey filepath contains file path of file to be saved
-        
+
         """
-        
+
         filepath = event.attr["filepath"]
-        
+
         dict_grid = self.code_array.dict_grid
-        
+
         self.saving = True
         self.need_abort = False
-        
+
         # Save file is compressed
         try:
             outfile = bz2.BZ2File(filepath, "wb")
-            
+
         except IOError:
             statustext = "Error opening file " + filepath + "."
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
             return False
-    
+
         # Header
         try:
             outfile.write("[Pyspread save file version]\n")
             outfile.write("0.1\n")
-            
+
         except IOError:
             statustext = "Error writing to file " + filepath + "."
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
             return False
-        
+
         # The output generators yield the lines for the outfile
         output_generators = [ \
             # Grid content
@@ -414,7 +411,7 @@ class FileActions(Actions):
             # Macros
             dict_grid.macros_to_strings(),
         ]
-        
+
         # Options for self._is_aborted
         abort_options_list = [ \
             ["Saving grid... ", len(dict_grid), 100000],
@@ -423,20 +420,20 @@ class FileActions(Actions):
             ["Saving column widths... ", len(dict_grid.col_widths)],
             ["Saving macros... ", dict_grid.macros.count("\n")],
         ]
-        
+
         # Save cycle
-        
+
         for generator, options in zip(output_generators, abort_options_list):
             for cycle, line in enumerate(generator):
                 try:
                     outfile.write(line.encode("utf-8"))
-                    
+
                 except IOError:
                     statustext = "Error writing to file " + filepath + "."
-                    post_command_event(self.main_window, StatusBarMsg, 
+                    post_command_event(self.main_window, StatusBarMsg,
                                        text=statustext)
                     return False
-                
+
                 # Enable abort during long saves
                 if self._is_aborted(cycle, *options):
                     self._abort_save(filepath, outfile)
@@ -445,14 +442,14 @@ class FileActions(Actions):
         # Save is done
 
         outfile.close()
-        
+
         self.saving = False
-        
+
         # Mark content as unchanged
         post_command_event(self.main_window, ContentChangedMsg, changed=False)
-        
+
         # Sign so that the new file may be retrieved without safe mode
-        
+
         self.sign_file(filepath)
 
 
@@ -461,33 +458,33 @@ class TableRowActionsMixin(Actions):
 
     def set_row_height(self, row, height):
         """Sets row height and marks grid as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         tab = self.grid.current_table
-        
+
         self.code_array.set_row_height(row, tab, height)
         self.grid.SetRowSize(row, height)
 
     def insert_rows(self, row, no_rows=1):
-        """Adds no_rows rows before row, appends if row > maxrows 
-        
+        """Adds no_rows rows before row, appends if row > maxrows
+
         and marks grid as changed
-        
+
         """
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.code_array.insert(row, no_rows, axis=0)
-        
+
     def delete_rows(self, row, no_rows=1):
         """Deletes no_rows rows and marks grid as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.code_array.delete(row, no_rows, axis=0)
 
 
@@ -496,109 +493,108 @@ class TableColumnActionsMixin(Actions):
 
     def set_col_width(self, col, width):
         """Sets column width and marks grid as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         tab = self.grid.current_table
-        
+
         self.code_array.set_col_width(col, tab, width)
         self.grid.SetColSize(col, width)
 
     def insert_cols(self, col, no_cols=1):
-        """Adds no_cols columns before col, appends if col > maxcols 
-        
+        """Adds no_cols columns before col, appends if col > maxcols
+
         and marks grid as changed
-        
+
         """
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.code_array.insert(col, no_cols, axis=1)
-        
+
     def delete_cols(self, col, no_cols=1):
         """Deletes no_cols column and marks grid as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.code_array.delete(col, no_cols, axis=1)
-        
+
 
 class TableTabActionsMixin(Actions):
     """Table tab controller actions"""
 
     def insert_tabs(self, tab, no_tabs=1):
         """Adds no_tabs tabs before table, appends if tab > maxtabs
-        
+
         and marks grid as changed
-        
+
         """
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.code_array.insert(tab, no_tabs, axis=2)
-        
+
         # Update TableChoiceIntCtrl
         shape = self.grid.code_array.shape
         post_command_event(self.main_window, ResizeGridMsg, shape=shape)
-        
 
     def delete_tabs(self, tab, no_tabs=1):
         """Deletes no_tabs tabs and marks grid as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.code_array.delete(tab, no_tabs, axis=2)
-        
+
         # Update TableChoiceIntCtrl
         shape = self.grid.code_array.shape
         post_command_event(self.main_window, ResizeGridMsg, shape=shape)
 
 
-class TableActions(TableRowActionsMixin, TableColumnActionsMixin, 
+class TableActions(TableRowActionsMixin, TableColumnActionsMixin,
                    TableTabActionsMixin):
     """Table controller actions"""
-    
+
     def __init__(self, grid):
         TableRowActionsMixin.__init__(self, grid)
         TableColumnActionsMixin.__init__(self, grid)
         TableTabActionsMixin.__init__(self, grid)
-        
+
         # Action states
-        
+
         self.pasting = False
-        
+
         # Bindings
-        
+
         self.main_window.Bind(wx.EVT_KEY_DOWN, self.on_key)
-    
+
     def on_key(self, event):
         """Sets abort if pasting and if escape is pressed"""
-        
+
         # If paste is running and Esc is pressed then we need to abort
-        
+
         if event.GetKeyCode() == wx.WXK_ESCAPE and \
            self.pasting or self.grid.actions.saving:
             self.need_abort = True
-        
+
         event.Skip()
-    
+
     def _abort_paste(self):
         """Aborts import"""
-        
+
         statustext = "Paste aborted."
         post_command_event(self.main_window, StatusBarMsg, text=statustext)
-        
+
         self.pasting = False
         self.need_abort = False
-    
+
     def _show_final_overflow_message(self, row_overflow, col_overflow):
         """Displays overflow message after import in statusbar"""
-        
+
         if row_overflow and col_overflow:
             overflow_cause = "rows and columns"
         elif row_overflow:
@@ -607,358 +603,361 @@ class TableActions(TableRowActionsMixin, TableColumnActionsMixin,
             overflow_cause = "columns"
         else:
             raise AssertionError, "Import cell overflow missing"
-        
+
         statustext = "The imported data did not fit into the grid " + \
                      overflow_cause + ". It has been truncated. " + \
                      "Use a larger grid for full import."
         post_command_event(self.main_window, StatusBarMsg, text=statustext)
-    
+
     def paste(self, tl_key, data):
         """Pastes data into grid from top left cell tl_key, marks grid changed
-        
+
         Parameters
         ----------
-        
+
         ul_key: Tuple
         \key of top left cell of paste area
         data: iterable of iterables where inner iterable returns string
         \tThe outer iterable represents rows
-        
+
         """
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.pasting = True
-        
+
         grid_rows, grid_cols, _ = self.grid.code_array.shape
-                
+
         self.need_abort = False
-        
+
         try:
             tl_row, tl_col, tl_tab = tl_key
-        
+
         except ValueError:
             tl_row, tl_col = tl_key
             tl_tab = self.grid.current_table
-        
+
         row_overflow = False
         col_overflow = False
-        
+
         no_pasted_cells = 0
-        
+
         for src_row, col_data in enumerate(data):
             target_row = tl_row + src_row
-            
+
             if self.grid.actions._is_aborted(src_row, "Pasting cells... "):
                 self._abort_paste()
                 return False
-            
+
             # Check if rows fit into grid
             if target_row >= grid_rows:
                 row_overflow = True
                 break
-            
+
             for src_col, cell_data in enumerate(col_data):
                 target_col = tl_col + src_col
-                
+
                 if target_col >= grid_cols:
                     col_overflow = True
                     break
-                
+
                 key = target_row, target_col, tl_tab
-                
+
                 try:
                     self.grid.code_array[key] = cell_data
-                    no_pasted_cells +=  1
+                    no_pasted_cells += 1
                 except KeyError:
                     pass
-        
+
         if row_overflow or col_overflow:
             self._show_final_overflow_message(row_overflow, col_overflow)
-            
+
         else:
             # Show actually pasted number of cells
-            
+
             plural = "s" if no_pasted_cells == 1 else ""
-            
+
             statustext = str(no_pasted_cells) + " cell" + plural + \
                          " pasted at cell " + str(tl_key)
-            
+
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
 
         self.pasting = False
 
     def change_grid_shape(self, shape):
         """Grid shape change event handler, marks content as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.grid.code_array.shape = shape
-        
+
         # Update TableChoiceIntCtrl
         post_command_event(self.main_window, ResizeGridMsg, shape=shape)
 
 
 class UnRedoActions(Actions):
     """Undo and redo operations"""
-    
+
     def undo(self):
         """Calls undo in model.code_array.unredo, marks content as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.grid.code_array.unredo.undo()
-        
+
     def redo(self):
         """Calls redo in model.code_array.unredo, marks content as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         self.grid.code_array.unredo.redo()
 
 
 class GridActions(Actions):
     """Grid level grid actions"""
-    
+
     def __init__(self, grid):
         Actions.__init__(self, grid)
-        
+
         self.code_array = grid.code_array
-        
-        self.prev_rowcol = [] # Last mouse over cell
-        
+
+        self.prev_rowcol = []  # Last mouse over cell
+
         self.main_window.Bind(EVT_COMMAND_GRID_ACTION_NEW, self.new)
-        self.main_window.Bind(EVT_COMMAND_GRID_ACTION_TABLE_SWITCH, 
+        self.main_window.Bind(EVT_COMMAND_GRID_ACTION_TABLE_SWITCH,
                               self.switch_to_table)
-    
+
     def new(self, event):
         """Creates a new spreadsheet. Expects code_array in event."""
-        
+
         # Grid table handles interaction to code_array
-        
+
         self.grid.actions.clear(event.shape)
-    
+
         _grid_table = GridTable(self.grid, self.grid.code_array)
         self.grid.SetTable(_grid_table, True)
-    
+
     # Zoom actions
-    
+
     def _zoom_rows(self, zoom):
         """Zooms grid rows"""
-        
-        self.grid.SetDefaultRowSize(self.grid.std_row_size * zoom, 
+
+        self.grid.SetDefaultRowSize(self.grid.std_row_size * zoom,
                                     resizeExistingRows=True)
         self.grid.SetRowLabelSize(self.grid.row_label_size * zoom)
-        
+
         for row, tab in self.code_array.row_heights:
             if tab == self.grid.current_table:
-                zoomed_row_size = self.code_array.row_heights[(row, tab)] * zoom
+                zoomed_row_size = \
+                    self.code_array.row_heights[(row, tab)] * zoom
                 self.grid.SetRowSize(row, zoomed_row_size)
-    
+
     def _zoom_cols(self, zoom):
         """Zooms grid columns"""
-        
-        self.grid.SetDefaultColSize(self.grid.std_col_size * zoom, 
+
+        self.grid.SetDefaultColSize(self.grid.std_col_size * zoom,
                                     resizeExistingCols=True)
         self.grid.SetColLabelSize(self.grid.col_label_size * zoom)
-    
+
         for col, tab in self.code_array.col_widths:
             if tab == self.grid.current_table:
                 zoomed_col_size = self.code_array.col_widths[(col, tab)] * zoom
                 self.grid.SetColSize(col, zoomed_col_size)
-    
+
     def _zoom_labels(self, zoom):
         """Adjust grid label font to zoom factor"""
-        
+
         labelfont = self.grid.GetLabelFont()
-        default_fontsize = get_font_from_data(config["font"]).GetPointSize() - 2
+        default_fontsize = \
+            get_font_from_data(config["font"]).GetPointSize() - 2
         labelfont.SetPointSize(max(1, int(round(default_fontsize * zoom))))
         self.grid.SetLabelFont(labelfont)
-    
+
     def zoom(self, zoom=None):
         """Zooms to zoom factor"""
-        
+
         status = True
-        
+
         if zoom is None:
             zoom = self.grid.grid_renderer.zoom
             status = False
-        
+
         # Zoom factor for grid content
         self.grid.grid_renderer.zoom = zoom
-        
+
         # Zoom grid labels
         self._zoom_labels(zoom)
-        
+
         # Zoom rows and columns
         self._zoom_rows(zoom)
         self._zoom_cols(zoom)
-        
+
         self.grid.ForceRefresh()
-        
+
         if status:
             statustext = u"Zoomed to {0:.2f}.".format(zoom)
-            
+
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
-    
+
     def zoom_in(self):
         """Zooms in by zoom factor"""
-        
+
         zoom = self.grid.grid_renderer.zoom
-        
+
         target_zoom = zoom * (1 + config["zoom_factor"])
-        
+
         if target_zoom < config["maximum_zoom"]:
             self.zoom(target_zoom)
-        
+
     def zoom_out(self):
         """Zooms out by zoom factor"""
-        
+
         zoom = self.grid.grid_renderer.zoom
-        
+
         target_zoom = zoom * (1 - config["zoom_factor"])
-        
+
         if target_zoom > config["minimum_zoom"]:
             self.zoom(target_zoom)
-    
+
     def on_mouse_over(self, key):
         """Displays cell code of cell key in status bar"""
-        
+
         row, col, tab = key
-        
+
         if (row, col) != self.prev_rowcol and row >= 0 and col >= 0:
             self.prev_rowcol[:] = [row, col]
-            
+
             hinttext = self.grid.GetTable().GetSource(row, col, tab)
-            
+
             if hinttext is None:
                 hinttext = ''
-            
+
             post_command_event(self.main_window, StatusBarMsg, text=hinttext)
-    
+
     def get_visible_area(self):
         """Returns visible area
-       
+
         Format is a tuple of the top left tuple and the lower right tuple
-        
+
         """
-        
+
         grid = self.grid
-        
+
         top = grid.YToRow(grid.GetViewStart()[1] * grid.ScrollLineX)
         left = grid.XToCol(grid.GetViewStart()[0] * grid.ScrollLineY)
-        
+
         # Now start at top left for determining the bottom right visible cell
-        
-        bottom, right = top, left 
-        
+
+        bottom, right = top, left
+
         while grid.IsVisible(bottom, left, wholeCellVisible=False):
             bottom += 1
-            
+
         while grid.IsVisible(top, right, wholeCellVisible=False):
             right += 1
-            
+
         # The derived lower right cell is *NOT* visible
-        
+
         bottom -= 1
         right -= 1
-        
+
         return (top, left), (bottom, right)
-    
+
     def switch_to_table(self, event):
         """Switches grid to table
-        
+
         Parameters
         ----------
-        
+
         event.newtable: Integer
         \tTable that the grid is switched to
-        
+
         """
-        
+
         newtable = event.newtable
-        
+
         no_tabs = self.grid.code_array.shape[2]
-        
+
         if 0 <= newtable <= no_tabs:
             self.grid.current_table = newtable
             self.main_window.table_choice.SetMax(newtable+1)
             self.main_window.table_choice.SetValue(newtable)
-            
+
             # Reset row heights and column widths by zooming
-            
+
             self.zoom()
-            
+
             statustext = u"Switched to table " + str(newtable)
-            
+
             post_command_event(self.main_window, StatusBarMsg, text=statustext)
 
     def get_cursor(self):
         """Returns current grid cursor cell (row, col, tab)"""
-        
+
         return self.grid.GetGridCursorRow(), self.grid.GetGridCursorCol(), \
                self.grid.current_table
 
     def set_cursor(self, value):
         """Changes the grid cursor cell.
-        
+
         Parameters
         ----------
-        
+
         value: 2-tuple or 3-tuple of String
         \trow, col, tab or row, col for target cursor position
-        
+
         """
-        
+
         if len(value) == 3:
             row, col, tab = value
-            
+
             if tab != self.cursor[2]:
-                post_command_event(self.main_window, GridActionTableSwitchMsg, 
+                post_command_event(self.main_window, GridActionTableSwitchMsg,
                                    newtable=tab)
         else:
             row, col = value
-        
+
         if not (row is None and col is None):
             self.grid.MakeCellVisible(row, col)
             self.grid.SetGridCursor(row, col)
-        
+
     cursor = property(get_cursor, set_cursor)
-    
+
 
 class SelectionActions(Actions):
     """Actions that affect the grid selection"""
-    
+
     def get_selection(self):
         """Returns selected cells in grid as Selection object"""
-        
+
         # GetSelectedCells: individual cells selected by ctrl-clicking
         # GetSelectedRows: rows selected by clicking on the labels
         # GetSelectedCols: cols selected by clicking on the labels
         # GetSelectionBlockTopLeft
-        # GetSelectionBlockBottomRight: For blocks of cells selected by dragging
+        # GetSelectionBlockBottomRight: For blocks selected by dragging
         # across the grid cells.
-        
+
         block_top_left = self.grid.GetSelectionBlockTopLeft()
         block_bottom_right = self.grid.GetSelectionBlockBottomRight()
         rows = self.grid.GetSelectedRows()
         cols = self.grid.GetSelectedCols()
         cells = self.grid.GetSelectedCells()
-        
+
         return Selection(block_top_left, block_bottom_right, rows, cols, cells)
-    
+
     def select_cell(self, row, col, add_to_selected=False):
         """Selects a single cell"""
-        
-        self.grid.SelectBlock(row, col, row, col, addToSelected=add_to_selected)
-    
+
+        self.grid.SelectBlock(row, col, row, col,
+                              addToSelected=add_to_selected)
+
     def select_slice(self, row_slc, col_slc, add_to_selected=False):
         """Selects a slice of cells
-        
+
         Parameters
         ----------
          * row_slc: Integer or Slice
@@ -967,19 +966,19 @@ class SelectionActions(Actions):
         \tColumns to be selected
          * add_to_selected: Bool, defaults to False
         \tOld selections are cleared if False
-        
+
         """
-        
+
         if not add_to_selected:
             self.grid.ClearSelection()
-        
+
         if row_slc == row_slc == slice(None, None, None):
             # The whole grid is selected
             self.grid.SelectAll()
-            
+
         elif row_slc.stop is None and col_slc.stop is None:
             # A block is selected:
-            self.grid.SelectBlock(row_slc.start, col_slc.start, 
+            self.grid.SelectBlock(row_slc.start, col_slc.start,
                                   row_slc.stop-1, col_slc.stop-1)
         else:
             for row in xrange(row_slc.start, row_slc.stop, row_slc.step):
@@ -988,25 +987,27 @@ class SelectionActions(Actions):
 
     def delete_selection(self):
         """Deletes selected cells, marks content as changed"""
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         selection = self.get_selection()
-        
-        del_keys = [key for key in self.grid.code_array if key[:2] in selection]
-        
+
+        del_keys = [key for key in self.grid.code_array \
+                        if key[:2] in selection]
+
         for key in del_keys:
             self.grid.actions.delete_cell(key)
-        
+
         self.grid.code_array.result_cache.clear()
 
+
 class FindActions(Actions):
     """Actions for finding inside the grid"""
-    
+
     def find(self, gridpos, find_string, flags):
         """Return next position of event_find_string in MainGrid
-        
+
         Parameters:
         -----------
         gridpos: 3-tuple of Integer
@@ -1015,11 +1016,11 @@ class FindActions(Actions):
         \tString to find in grid
         flags: Int
         \twx.wxEVT_COMMAND_FIND flags
-        
+
         """
-        
+
         findfunc = self.grid.code_array.findnextmatch
-        
+
         if "DOWN" in flags:
             if gridpos[0] < self.grid.code_array.shape[0]:
                 gridpos[0] += 1
@@ -1038,17 +1039,17 @@ class FindActions(Actions):
                 gridpos[2] -= 1
             else:
                 gridpos = [dim - 1 for dim in self.grid.code_array.shape]
-        
+
         return findfunc(tuple(gridpos), find_string, flags)
-        
+
     def replace(self, findpos, find_string, replace_string):
         """Replaces occurrences of find_string with replace_string at findpos
-        
+
         and marks content as changed
-        
+
         Parameters
         ----------
-        
+
         findpos: 3-Tuple of Integer
         \tPosition in grid that shall be replaced
         find_string: String
@@ -1057,22 +1058,23 @@ class FindActions(Actions):
         \tString to be used for replacement
 
         """
-        
+
         # Mark content as changed
         post_command_event(self.main_window, ContentChangedMsg, changed=True)
-        
+
         old_code = self.grid.code_array(findpos)
         new_code = old_code.replace(find_string, replace_string)
-    
+
         self.grid.code_array[findpos] = new_code
         self.grid.actions.cursor = findpos
-        
+
         statustext = "Replaced '" + old_code + "' with '" + new_code + \
                      "' in cell " + unicode(list(findpos)) + "."
-                     
+
         post_command_event(self.main_window, StatusBarMsg, text=statustext)
 
-class AllGridActions(FileActions, TableActions, UnRedoActions, 
+
+class AllGridActions(FileActions, TableActions, UnRedoActions,
                      GridActions, SelectionActions, FindActions, CellActions):
     """All grid actions as a bundle"""
 
@@ -1084,23 +1086,22 @@ class AllGridActions(FileActions, TableActions, UnRedoActions,
         SelectionActions.__init__(self, grid)
         FindActions.__init__(self, grid)
         CellActions.__init__(self, grid)
-        
-    
+
     def _replace_bbox_none(self, bbox):
         """Returns bbox, in which None is replaced by grid boundaries"""
-        
+
         (bb_top, bb_left), (bb_bottom, bb_right) = bbox
-        
+
         if bb_top is None:
             bb_top = 0
-        
+
         if bb_left is None:
-            bb_left = 0    
-        
+            bb_left = 0
+
         if bb_bottom is None:
             bb_bottom = self.code_array.shape[0] - 1
-        
+
         if bb_right is None:
-            bb_right = self.code_array.shape[1] - 1  
-        
-        return (bb_top, bb_left), (bb_bottom, bb_right)
+            bb_right = self.code_array.shape[1] - 1
+
+        return (bb_top, bb_left), (bb_bottom, bb_right)
\ No newline at end of file
